@@ -2,7 +2,13 @@
 git update-index --refresh >/dev/null
 git diff-index --quiet HEAD --
 
-test $? -eq 0 || echo "ERROR: the repo is dirty clean it before building!"; exit 1
+
+if [[ $? -ne 0 ]]; then
+	echo "ERROR: the repo is dirty clean it before building!"
+    exit 1
+fi
+
+echo got here
 
 # define where the version file is found
 VERSION_FILE=src/nef_pipelines/VERSION
@@ -11,11 +17,14 @@ VERSION_FILE=src/nef_pipelines/VERSION
 cd /Users/garythompson/Dropbox/nef_pipelines/nef_pipelines
 
 #clear dists but don't complain if its empty
+if [ -n "$ZSH_VERSION" ]; then
+  setopt localoptions rmstarsilent
+fi
 rm -rf  dist/* || true
 
 # increase version and tag it
 ver  --file $VERSION_FILE  up --patch
-ver  --file $VERSION_FILE tag
+
 
 # grab the version
 VERSION=`ver --file $VERSION_FILE |  awk '{print $3}'`
@@ -24,12 +33,18 @@ VERSION=`ver --file $VERSION_FILE |  awk '{print $3}'`
 git add src/nef_pipelines/VERSION
 git commit -m "updated version to $VERSION" --no-verify
 
+ver  --file $VERSION_FILE tag
+
 # stash any uncommited changes to avoid version+1 errors
-git stash
+stash_message="stashed-for-pypi-drop-${VERSION}-`date +%s`"
+git stash --message ${stash_message}
 
 #build and publish
 tox -e build  # to build your package distribution
 tox -e publish -- --repository pypi
 
-# unstash uncommitted changes
-git stash pop
+git stash list  | grep -q ${stash_message}
+if [[ $? -eq 0 ]]; then
+  # unstash uncommitted changes
+  git stash pop
+fi
