@@ -1,16 +1,22 @@
-SPECTRUM_FRAME_CATEGORY = "nef_nmr_spectrum"
-SPECTRUM_DIMENSION_LOOP_CATEGORY = "nef_spectrum_dimension"
+NEF = "nef"
+SF = "sf"
+
+SHIFT_LIST_FRAME_CATEGORY = f"{NEF}_chemical_shift_list"
+
+SPECTRUM_FRAME_CATEGORY = f"{NEF}_nmr_spectrum"
+SPECTRUM_DIMENSION_LOOP_CATEGORY = f"{NEF}_spectrum_dimension"
 SPECTRUM_DIMENSION_TRANSFER_LOOP_CATEGORY = (
     f"{SPECTRUM_DIMENSION_LOOP_CATEGORY}_transfer"
 )
-SPECTRUM_PEAK_LOOP_CATEGORY = "nef_peak"
+SPECTRUM_PEAK_LOOP_CATEGORY = f"{NEF}_peak"
 
-SF_CATEGORY = "sf_category"
-SF_FRAMECODE = "sf_framecode"
+SF_CATEGORY = f"{SF}_category"
+SF_FRAMECODE = f"{SF}_framecode"
 NUM_DIMENSIONS = "num_dimensions"
 CHEMICAL_SHIFT_LIST = "chemical_shift_list"
 EXPERIMENT_TYPE = "experiment_type"
 EXPERIMENT_CLASSIFICATION = "experiment_classification"
+CCPN_COMMENT = "ccpn_comment"
 
 SPECTRUM_FRAME_TAGS = (
     SF_CATEGORY,
@@ -89,12 +95,16 @@ VOLUME_UNCERTAINTY = "volume_uncertainty"
 PEAK_LOOP_TAGS = [
     INDEX,
     PEAK_ID,
-    CHAIN_CODE__DIMENSION_INDEX,
-    SEQUENCE_CODE__DIMENSION_INDEX,
-    RESIDUE_NAME__DIMENSION_INDEX,
-    ATOM_NAME__DIMENSION_INDEX,
-    POSITION__DIMENSION_INDEX,
-    POSITION_UNCERTAINTY__DIMENSION_INDEX,
+    [
+        CHAIN_CODE__DIMENSION_INDEX,
+        SEQUENCE_CODE__DIMENSION_INDEX,
+        RESIDUE_NAME__DIMENSION_INDEX,
+        ATOM_NAME__DIMENSION_INDEX,
+    ],
+    [
+        POSITION__DIMENSION_INDEX,
+        POSITION_UNCERTAINTY__DIMENSION_INDEX,
+    ],
     HEIGHT,
     HEIGHT_UNCERTAINTY,
     VOLUME,
