@@ -1,12 +1,14 @@
 import string
 from collections import Counter
 from dataclasses import replace
+from enum import auto
 from pathlib import Path
 from textwrap import dedent
 from typing import Dict, Iterable, List, Optional, Tuple, Union
 
 from ordered_set import OrderedSet
 from pynmrstar import Entry, Loop, Saveframe
+from strenum import LowercaseStrEnum
 
 from nef_pipelines.lib.constants import NEF_UNKNOWN
 from nef_pipelines.lib.nef_lib import UNUSED, loop_row_namespace_iter
@@ -21,19 +23,27 @@ from nef_pipelines.lib.util import (
     read_from_file_or_exit,
 )
 
+
+class MoleculeType(LowercaseStrEnum):
+    PROTEIN = auto()
+    RNA = auto()
+    DNA = auto()
+    CARBOH = auto()
+
+
 NEF_CHAIN_CODE = "chain_code"
 ANY_CHAIN = "_"
 
 
 def chain_code_iter(
-    user_chain_codes: Union[str, List[str]] = "", exclude: Union[str, List[str]] = ()
+    user_chain_codes: List[str] = "", exclude: List[str] = ()
 ) -> Iterable[str]:
     """
-    split input string into chain codes separated by .s, and yield them.
-    Then yield any remaining letters of the upper case alphabet till they run out
+    Yield chain codes in user chain codes and once exhausted yield any remaining letters of the upper case alphabet
+    till they run out. A list of chain codes to not use can be provided...
 
     Args:
-        user_chain_codes (str):  string of dot separated chain codes
+        user_chain_codes (str):  string of dot separated chain codes or a list of chain codes
         exclude: chain codes to not include in the iteration
 
     Returns:
@@ -42,19 +52,9 @@ def chain_code_iter(
 
     ascii_uppercase = list(string.ascii_uppercase)
 
-    if isinstance(user_chain_codes, str):
-        if "." in user_chain_codes:
-            user_chain_codes = user_chain_codes.split(".")
-
-    if isinstance(exclude, str):
-        if "." in exclude:
-            exclude = exclude.split(".")
-
-    chain_codes = user_chain_codes if user_chain_codes else ascii_uppercase
-
     seen_codes = set()
 
-    for chain_code in chain_codes:
+    for chain_code in user_chain_codes:
         seen_codes.add(chain_code)
         if chain_code not in exclude:
             yield chain_code
@@ -160,7 +160,22 @@ def sequence_to_nef_frame(
     return nef_frame
 
 
-TRANSLATIONS_3_1 = {
+class MoleculeTypes(LowercaseStrEnum):
+    PROTEIN = auto()
+    DNA = auto()
+    RNA = auto()
+    CARBOH = auto()
+    LIGAND = auto()
+    OTHER = auto()
+
+
+TRANSLATIONS_3_1_DNA = {"DG": "G", "DC": "C", "DT": "T", "DA": "A"}
+TRANSLATIONS_1_3_DNA = {value: key for (key, value) in TRANSLATIONS_3_1_DNA.items()}
+
+TRANSLATIONS_3_1_RNA = {"G": "G", "C": "C", "A": "A", "U": "U", "I": "I"}
+TRANSLATIONS_1_3_RNA = {value: key for (key, value) in TRANSLATIONS_3_1_RNA.items()}
+
+TRANSLATIONS_3_1_PROTEIN = {
     "ALA": "A",
     "ARG": "R",
     "ASN": "N",
@@ -182,7 +197,26 @@ TRANSLATIONS_3_1 = {
     "TYR": "Y",
     "VAL": "V",
 }
-TRANSLATIONS_1_3 = {value: key for (key, value) in TRANSLATIONS_3_1.items()}
+TRANSLATIONS_1_3_PROTEIN = {
+    value: key for (key, value) in TRANSLATIONS_3_1_PROTEIN.items()
+}
+
+TRANSLATIONS_1_3 = {
+    MoleculeTypes.PROTEIN: TRANSLATIONS_1_3_PROTEIN,
+    MoleculeTypes.DNA: TRANSLATIONS_1_3_DNA,
+    MoleculeTypes.RNA: TRANSLATIONS_1_3_RNA,
+    MoleculeTypes.CARBOH: None,
+    MoleculeTypes.OTHER: None,
+    MoleculeTypes.LIGAND: None,
+}
+TRANSLATIONS_3_1 = {
+    MoleculeTypes.PROTEIN: TRANSLATIONS_3_1_PROTEIN,
+    MoleculeTypes.DNA: TRANSLATIONS_3_1_DNA,
+    MoleculeTypes.RNA: TRANSLATIONS_3_1_RNA,
+    MoleculeTypes.CARBOH: None,
+    MoleculeTypes.OTHER: None,
+    MoleculeTypes.LIGAND: None,
+}
 
 
 class BadResidue(Exception):
@@ -194,25 +228,29 @@ class BadResidue(Exception):
 
 
 def translate_1_to_3(
-    sequence: str,
-    translations: Dict[str, str] = TRANSLATIONS_1_3,
-    unknown: Optional[str] = None,
+    sequence: str, molecule_type=MoleculeTypes.PROTEIN, unknown: Optional[str] = None
 ) -> List[str]:
     """
     Translate a 1 letter sequence to a 3 letter sequence
     Args:
         sequence (str): 1 letter sequence
-        translations (Dict[str, str]): a list of translations for single amino acid codes to 3 letter residue names
+        molecule_type (MoleculeTypes): type of molecule to translate residue types
         unknown (Optional[str]): optional name for residues if they are unknown, if set no error is raised if a
                                  1 letter residue name is not recognised
     Returns List[str]:
         a list of 3 residue codes
+        :param type:
 
     """
+
+    translations = TRANSLATIONS_1_3[molecule_type]
+
     result = []
     for i, residue_name_1let in enumerate(sequence):
         residue_name_1let = residue_name_1let.upper()
-        if residue_name_1let in translations:
+        if translations is None:
+            result.append(residue_name_1let)
+        elif residue_name_1let in translations:
             result.append(translations[residue_name_1let])
         else:
             if unknown:
@@ -230,14 +268,14 @@ def translate_1_to_3(
 
 
 def translate_3_to_1(
-    sequence: List[str], translations: Dict[str, str] = TRANSLATIONS_3_1
+    sequence: List[str], molecule_type=MoleculeTypes.PROTEIN
 ) -> List[str]:
     """
 
     Translate a 3 letter sequence to a 1 letter sequence
     Args:
         sequence (str): 3 letter sequence
-        translations (Dict[str, str]): a list of translations for single amino acid codes to 3 letter residue names
+        molecule_type (MoleculeTypes): type of molecule to translate residue types
 
     Returns List[str]:
         a list of 1 residue codes
@@ -245,14 +283,27 @@ def translate_3_to_1(
     :param sequence:
     :return:
     """
+
+    translations = TRANSLATIONS_3_1[molecule_type]
+
     result = []
-    for i, resn in enumerate(sequence, start=1):
-        resn = resn.upper()
-        if resn in translations:
-            result.append(translations[resn])
+    for i, residue_name in enumerate(sequence, start=1):
+        residue_name = residue_name.upper()
+        if translations is None:
+            if len(residue_name) == 1:
+                result.append(residue_name)
+            else:
+                msg = f"""
+                    it isn't possible to translate the residue name {residue_name} to a 1 letter code
+                    the molecule type {molecule_type} doesn't have one letter codes and the residue name: {residue_name}
+                    is longer than one letter and so can't be passed through
+                """
+                exit_error(msg)
+        if residue_name in translations:
+            result.append(translations[residue_name])
         else:
             msg = f"""
-            unknown residue {resn}
+            unknown residue {residue_name}
             in sequence {chunks(' '.join(sequence), 10)}
             at residue number {i}
             """
@@ -578,10 +629,15 @@ def make_chunked_sequence_1let(
 def residues_to_residue_name_lookup(
     sequence: List[SequenceResidue],
 ) -> Dict[Tuple[str, str], str]:
-    return {
-        (residue.chain_code, str(residue.sequence_code)): residue.residue_name
-        for residue in sequence
-    }
+
+    result = None
+    if len(sequence) > 0:
+        result = {
+            (residue.chain_code, str(residue.sequence_code)): residue.residue_name
+            for residue in sequence
+        }
+
+    return result
 
 
 def replace_chain_in_atom_labels(
