@@ -2,7 +2,7 @@ from dataclasses import dataclass
 from enum import auto
 from typing import Dict, List, Optional, Union
 
-from strenum import StrEnum
+from strenum import LowercaseStrEnum, StrEnum
 
 
 class Linking(StrEnum):
@@ -161,19 +161,31 @@ class RdcRestraint:
     weight: Optional[float] = None
 
 
+class PeakFitMethod(LowercaseStrEnum):
+    GAUSSIAN = auto()
+    LORENTZIAN = auto()
+    SPLINE = auto()
+
+
 @dataclass(frozen=True, order=True)
 class NewPeak:
 
-    shifts: List[ShiftData]
+    shifts: List[
+        ShiftData
+    ]  # shifts we support this by maving mutiples peaks with the same id
 
     id: Optional[int] = None
     height: Optional[float] = None
     height_uncertainty: Optional[float] = None
     volume: Optional[float] = None
     volume_uncertainty: Optional[float] = None
+    peak_fit_method: Optional[Union[str, PeakFitMethod]] = None
+    figure_of_merit: Optional[float] = None
+    comment: str = ""
 
 
 @dataclass
 class DimensionInfo:
     axis_code: str  # this is the isotope code for us...
+    axis_name: str = None
     axis_unit: Optional[str] = "ppm"
