@@ -6,9 +6,10 @@ import sys
 import traceback
 from argparse import Namespace
 from enum import auto
+from math import floor
 from pathlib import Path
 from textwrap import dedent
-from typing import Any, Dict, Iterator, List, Optional, TextIO, TypeVar, Union
+from typing import Any, Dict, Iterator, List, Optional, TextIO, Tuple, TypeVar, Union
 
 import click
 from cacheable_iter import iter_cache
@@ -29,6 +30,8 @@ from nef_pipelines.lib.header_lib import (
 )
 from nef_pipelines.lib.structures import LineInfo
 
+FOUR_SPACES = " " * 4
+
 STDIN = Path("-")
 STDOUT = Path("-")
 
@@ -413,9 +416,10 @@ def exit_error(msg, exception=None):
     command = _script_to_command(script)
 
     print(f"ERROR [in: {command}]: {msg[0]}", file=sys.stderr)
+    print(file=sys.stderr)
 
     for line in msg[1:]:
-        print(f"       {line}", file=sys.stderr)
+        print(f"  {line}", file=sys.stderr)
     print("exiting...", file=sys.stderr)
     sys.exit(EXIT_ERROR)
 
@@ -783,3 +787,108 @@ def _row_to_table(rows: Dict[str, str], headers=("tag", "value")) -> List[List[s
         values.append([key, value])
     value_string = tabulate(values, headers="firstrow")
     return value_string
+
+
+def strings_to_table_terminal_sensitive(
+    strings: str,
+    used_width: int = 0,
+    min_width: int = 20,
+    fallback_terminal_width: int = 100,
+):
+    """
+    given a list of strings convert them to a table where the number of columns os compatible with the terminal width
+    :param strings: a list of strings to tabulate
+    :param used_width: any width of the terminal already used
+    :param min_width: the minum width for a table column
+    :param fallback_terminal_width: if the terminal width can't be determined use this width
+    :return: a list of list where each sub list is a row, which is  suitable for formatting with tabulate.tabulate
+    """
+    try:
+        width, _ = os.get_terminal_size()
+    except Exception:
+        width = fallback_terminal_width
+
+    width -= used_width
+
+    # apply a sensible minimum width
+    if width < min_width:
+        width = min_width
+
+    if len(strings) > 0:
+        frame_name_widths = [len(frame_name) for frame_name in strings]
+        max_frame_name_width = max(frame_name_widths)
+
+        columns = int(floor(width / (max_frame_name_width + 1)))
+        column_width = int(floor(width / columns))
+
+        columns = 1 if columns == 0 else columns
+
+        strings = [frame_name.rjust(column_width) for frame_name in strings]
+        table_list = chunks(strings, columns)
+    else:
+        table_list = [
+            [],
+        ]
+
+    return list(table_list)
+
+
+def strings_to_tabulated_terminal_sensitive(
+    strings: str,
+    used_width: int = 0,
+    min_width: int = 20,
+    fallback_terminal_width: int = 100,
+):
+
+    table = strings_to_table_terminal_sensitive(
+        strings, used_width, min_width, fallback_terminal_width
+    )
+    return tabulate(table, tablefmt="plain")
+
+
+def strip_characters_left(target: str, letters: str) -> Tuple[str, str]:
+
+    """
+     strip the characters from letters from the left of the target and return a tuple containing
+        1. the string without the stripped letters
+        2. the letters that were stripped off
+
+    :param target: the string to strip
+    :param letters:  the letters to be stripper
+    :return: a tuple of the form (<stripped-string>, <stripped-letters>)
+    """
+
+    remaining = target.lstrip(letters)
+
+    num_stripped = len(target) - len(remaining)
+    stripped = target[:num_stripped] if num_stripped > 0 else ""
+
+    return stripped, remaining
+
+
+def strip_characters_right(target: str, letters: str) -> Tuple[str, str]:
+    """
+    strip the characters from letters from the right of the target and return a tuple containing
+        1. the string without the stripped letters
+        2. the letters that were stripped off
+
+    :param target: the string to strip
+    :param letters:  the letters to be stripper
+    :return: a tuple of the form (<stripped-string>, <stripped-letters>)
+    """
+
+    remaining = target.rstrip(letters)
+    num_stripped = len(target) - len(remaining)
+    stripped = target[-num_stripped:] if num_stripped > 0 else ""
+
+    return remaining, stripped
+
+
+def strip_line_comment(line: str, comment_character: str = "#") -> Tuple[str, str]:
+    comment = None
+    if comment_character in line:
+        index = line.index(comment_character)
+        comment = line[index + 1 :]
+        line = line[:index]
+
+    return line, comment
