@@ -8,14 +8,14 @@ import_app = typer.Typer()
 
 if nef_app.app:
 
-    nef_app.app.add_typer(app, name="mars", help="- export mars [shifts and sequences]")
+    nef_app.app.add_typer(
+        app, name="mars", help="- read and write mars [shifts and sequences]"
+    )
 
     app.add_typer(
         export_app, name="export", help="- export mars [shifts and sequences]"
     )
 
-    nef_app.app.add_typer(app, name="mars", help="- import mars [shifts]")
-
     app.add_typer(import_app, name="import", help="- import mars [shifts]")
 
     # import of specific importers must be after app creation to avoid circular imports
